@@ -51,6 +51,7 @@ pub fn compile(unit_code: &str, metadata: &[String; 2], version: &str) {
             "}\n",
             "\\begin{document}\n",
             "\\maketitle\n",
+            "\\toc\n",
             "\\solprint\n",
             "\\end{document}\n",
         ]
@@ -99,12 +100,16 @@ pub fn compile(unit_code: &str, metadata: &[String; 2], version: &str) {
     )
     .expect(&["Error copying metadata.tex to ", &build_str].concat());
 
-    Command::new("sh")
-        .args(["-c", "latexmk -pdf -f", &problem_tex_path])
+    let unit_latexmk = Command::new("latexmk")
+        .args(["-pdf", "-f", &unit_tex_path])
         .output()
-        .ok();
+        .expect("Failed to execute latexmk");
 
-    println!("{}", &["Finished compiling ", &unit_pdf_path].concat());
+    if unit_latexmk.status.success() {
+        println!("{}", &["Finished compiling ", &unit_pdf_path].concat());
+    } else {
+        println!("{}", &["Warning: Failed to compile ", &unit_pdf_path].concat());
+    }
 
     fs::write(
         ["S", unit_code, version, "metadata.tex"].join("-"),
@@ -123,12 +128,16 @@ pub fn compile(unit_code: &str, metadata: &[String; 2], version: &str) {
     )
     .expect(&["Error copying metadata.tex to ", &build_str].concat());
 
-    Command::new("sh")
-        .args(["-c", "latexmk -pdf -f", &solutions_tex_path])
+    let solutions_latexmk = Command::new("latexmk")
+        .args(["-pdf", "-f", &solutions_tex_path])
         .output()
-        .ok();
+        .expect("Failed to execute latexmk");
 
-    println!("{}", &["Finished compiling ", &solutions_pdf_path].concat());
+    if solutions_latexmk.status.success() {
+        println!("{}", &["Finished compiling ", &solutions_pdf_path].concat());
+    } else {
+        println!("{}", &["Warning: Failed to compile ", &solutions_pdf_path].concat());
+    }
 
     env::set_current_dir("../").ok();
 
